function F = DiscLogistic_solution(p,resamppts,fixedpara)
% Discontinuous logistic model is equations (S2.1) and (S2.2)
% Output is concatenated solutions give by equation (S2.3)

% Inputs are: p - parameter values
%             resamppts - time points that were resampled
%             fixedpara - fixed parameters that are not estimated
%                         Includes removal rate d and time points 
%                         of peak density in time series
% Output is solution given by equation (S2.3) 

    k1 = p(1); % Competition coefficient before diapausing
    r = p(2); % Max reproduction rate
    k2 = p(3); % Competition coefficient after diapausing
    m = p(4); % mortality rate
    H0 = p(5:end); % Initial condition
    d = fixedpara(1); % Removal rate due to destructive sampling
    peak_pt = fixedpara(2:end); % peaks in density
    Time = (7:5:52)-7; % Days when samples were taken
    
    para1 = [k1 r d]; % Parameters for piece 1 of model
    para2 = [k2 r m d]; % Parameters for piece 2 of model
    F= []; % Collected densities for all replicates
    
    % Simulate model for each replicate
    for jj = 1:length(H0);
        % Time points that were resampled
        resamp = resamppts(1+(jj-1)*10:jj*10);
                
        % Write model as dx/dt = rbar*x*(1-kibar*x)
        res1 = zeros(10,1); % model densities at each time point
        rbar = r-d; % max exp growth rate
        k1bar = k1*r/rbar; % comp coeff before diapausing
        k2bar = (r-m)*k2/rbar; %  comp coeff after diapausing

        % peak density 
        peak_den = H0(jj)/(k1bar*H0(jj)+(1-k1bar*H0(jj))*...
            exp(-rbar*Time(peak_pt(jj))));

        % Time when 0=(1-k2*S) for diapausing model
        transpt = -log(k2*peak_den)/(-m-d)+Time(peak_pt(jj)); 
        transden = 1/k2; % At t = transpt, host density = 1/k2
        
        % For each resampled time point compute density using 
        % equation (S2.3)
        for ii = 1:length(resamp)
            if resamp(ii)<peak_pt(jj)+0.5 
                % logistic growth upto peak
                res1(ii) = H0(jj)/(k1bar*H0(jj)+(1-k1bar*H0(jj))*...
                    exp(-rbar*Time(resamp(ii))));
            else if Time(resamp(ii))<transpt 
                    % exp decline from peak to transition point
                    res1(ii) = peak_den*exp(-(m+d)*...
                        abs(Time(resamp(ii))-Time(peak_pt(jj))));
                else
                    % logistic growth after exp decline
                    res1(ii) = transden/(k2bar*transden+...
                        (1-k2bar*transden)*exp(-rbar*...
                        abs(transpt-Time(resamp(ii)))));
                end
            end
        end
        % Output is density at each point in time for each replicate
        F = [F; res1];
    end
                    
                         
end
