% ConfidenceIntervals_rKalpha
% Generates bootstrapped confidence intervals for r, K, alpha_ni
% for Native Host

clear all
format long
rng('shuffle')

num = 1000; % number of re-samples
alpha_ni= zeros(num,1);
alpha = 0.05; % Confidence interval parameter

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Resampling of long-term densities of `Combined, no disease' treatment

Times = 0:5:95;

%%% Get data 
    DataCombined = xlsread('Mesocosm data1.xls');
       
    DataCN = zeros(10,10);
    for ii =1:10;
        DataCN(10:-1:1,ii) = DataCombined((1:10)+(ii-1)*10,20);
        DataCI(10:-1:1,ii) = DataCombined((1:10)+(ii-1)*10,21);
    end
    
    % Shift data so peaks in native density align
    ShiftDataCN = NaN(20,10);
    AvgShiftCN0 = NaN(20,1);
    AvgShiftCN = NaN(20,1);
    ShiftDataCI = NaN(20,10);
    AvgShiftCI0 = NaN(20,1);
    AvgShiftCI = NaN(20,1);
    
    for jj =1:10;
        zz = find(DataCN(:,jj)==max(DataCN(:,jj)));
        ShiftDataCN((10-(zz-1)):(20-(zz)),jj) = DataCN(:,jj);
        ShiftDataCI((10-(zz-1)):(20-(zz)),jj) = DataCI(:,jj);
    end
    
    % Exclude mesocosm 5 because of double peak in native
    % Exclude mesocosm 2 because no invasive density at shifted time points
    keepCN = [1 3:4 6:10];
    

%%% Resampling 
    % Only time points 14 and 15 used to compute mean long term density
    MeanNatDen = zeros(num,1); % Mean Native Density
    MeanInvDen = zeros(num,1); % Mean Invasive Density
        
     for jj = 1:num
        % resample from replicates
        resamp = datasample(keepCN,length(keepCN),'Replace',true);    
        
        % Collect resampled data
        NatDen= [ShiftDataCN(14,resamp) ShiftDataCN(15,resamp)];
        InvDen= [ShiftDataCI(14,resamp) ShiftDataCI(15,resamp)];
        
        % Estimate long-term density
        
        MeanNatDen(jj) = mean(NatDen);
        MeanInvDen(jj) = mean(InvDen);
     end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%     
%% Resampling of time series of `Native, no disease' treatment

%%% Get data
    DataNative = xlsread('Mesocosm data.xls','dent-only treatments');
    Data = zeros(10,10);
    for jj =1:10;
        Data(10:-1:1,jj) = DataNative((1:10)+(jj-1)*10,12);
    end
    
    % Exclude mesocosm 2,4,9,10 for double peaks
    % Exclude mesocosm 6 because too few data points after peak
    keepN = [1 3 5 7 8]; % Time series being fit
    repnum = 1:length(keepN);
    DataKeep=Data(1:10,keepN); % Mesocosms not excluded
    peak_pt = [5 5 5 5 7]; % Time points where peak density occurs
    delta = 1/75; % Dilution Rate
    Time = 7:5:52; % Days when samples were taken

%%% Parameters for parameter fitting
    init_k1 = 9.393e-4;
    init_r = 0.297;
    init_k2 = 0.022;
    init_m = 0.149;
    init_H0=[22.1  14.6  35 1.17 0.136];
        % init_H0 is initial density in each replicate
    
    options = optimset('MaxFunEvals',5000);
    fixedpara = [delta peak_pt]; % dilution rate is fixed
         % points where peak density occur are also fixed
    
%%% Resampling 
    % Estimated parameters for re-sampled sets
    est_k1 = zeros(num,1);
    est_r1 = zeros(num,1);
    est_k2 = zeros(num,1);
    est_m = zeros(num,1);
    est_H0 = zeros(num,length(keepN)); % initial conditions
    est_K = zeros(num,1);
       
    % jj is index for re-sampling
    for jj = 1:num
        
        resamppts=[]; % Resampled data points
        DataRS=[]; % Resampled densities at data points
                
        % ii is index for replicate
        for ii = 1:length(keepN)
            % Choose 10 time points with replacement from time series ii
            resamp = sort(datasample(1:10,10,'Replace',true));
            % Ensure at least 2 data points on each side of peak
            while sum(resamp<peak_pt(ii))<2 || sum(resamp>peak_pt(ii))<2
                resamp = sort(datasample(1:10,10,'Replace',true));
            end
            
            % Collect resampling points
            resamppts = [resamppts; resamp'];
            % Collect resampled data
            DataRS = [DataRS; DataKeep(resamp,ii)];
        end
        
        % Initial parameter estimates
        para1 = [init_k1 init_r init_k2 init_m init_H0];
        
        % Fit solution to ODE model to resampled data
	% ODE model is equations (S2.1) and (S2.2)
        % Solution is given by equation (S2.3)
        [FitParms, resnorm, residual] = lsqcurvefit(...
        @(para,resamppts)SplitLogistic_solution(para,resamppts,fixedpara),...
        para1,resamppts,DataRS,zeros(1,length(para1)),[],options);
    
        % Save estimated parameter values
        est_k1(jj) = FitParms(1);
        est_r1(jj) = FitParms(2);% estimated r values (r = b-m)
        est_k2(jj) = FitParms(3);% estimated k2 values
        est_m(jj) = FitParms(4);% estimated m values
        est_H0(jj,:) = FitParms(5:end); % estimated initial conditions
        est_K(jj) = est_r1(jj)/((est_r1(jj)+est_m(jj))*est_k2(jj)); 
            % estimated K value                
    end % End of bootstrapping
  
%%% Compute confidence intervals 

   % Compute alpha_{in} values from bootstrap estimates of parms
   % values sorted to compute confidence interval
   alpha_ni = sort(((est_r1-delta).*est_K-MeanNatDen.*est_r1)./(...
       est_r1.*MeanInvDen));
   % alpha_{in} confidence interval
   ConfInt_alpha = [alpha_ni(ceil(alpha*num)) alpha_ni(end-ceil(alpha*num))];
   % r_i confidence interval
   rvals = sort(est_r1);
   ConfInt_r = [rvals(ceil(alpha*num)) rvals(end-ceil(alpha*num))];
   % K_i confidence interval
   Kvals = sort(est_K);
   ConfInt_K = [Kvals(ceil(alpha*num)) Kvals(end-ceil(alpha*num))];

%%% Save distributions of bootstrap estimates of parameters
   fid = fopen('Native_r.txt','w');
   fprintf(fid, '%f \n', est_r1);
   fclose(fid);

   fid = fopen('Native_K.txt','w');
   fprintf(fid, '%f \n', est_K);
   fclose(fid);

   fid = fopen('alpha_ni.txt','w');
   fprintf(fid, '%f \n', alpha_ni);
   fclose(fid);
   
   
%%% Plot distribution of bootstrap estimates of alpha_{ni}
   figure;  
   hist(alpha_ni,40,'k')
   set(get(gca,'child'),'FaceColor','k','EdgeColor','k');
   xlabel('competition coefficient, \alpha_{ni}','FontSize',16)
   ylabel('Number','FontSize',16)
   set(gca,'Box','on','FontSize',16);

    


