%%% NativeNoDiseaseFitting_script.m
% Fits time series from 'Native, no disease' mesocosms
% Model is given by equations (S2.1) and (S2.2)
% Solution given in equation (S2.3) is fit to time series
% Fits are constrained to so that parameters are the same 
% for all replicates

clear all
format long

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Get data
    DataNative = xlsread('Mesocosm data.xls','dent-only treatments','');
    Data = zeros(10,10);
    for jj =1:10;
        Data(10:-1:1,jj) = DataNative((1:10)+(jj-1)*10,12);
    end
    
    % Excluded mesocosm 2,4,9,10 for double peaks
    % Excluded mesocosm 6 because too few data points after peak
    keepN = [1 3 5 7 8]; % Time series being fit
    peak_pt = [5 5 5 5 7]; % Time points where peak density occurs
    d = 1/75; % Dilution Rate
    Time = 7:5:52; % Days when samples were taken
        
    DataN=[];
    for jj = keepN
        DataN = [DataN; Data(1:10,jj)];
    end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Fit model to time series
    
    % Estimated parameters to save
    est_k1 = 0; % estimated k1 values
    est_r1 = 0; % estimated r values (r = b-m)
    est_k2 = 0; % estimated k2 values
    est_m = 0;  % estimated m values
    est_H0 = zeros(1,length(keepN)); % estimated initial densities
    error_1 = 0; % SSres (sum of residuals^2)
    R2 = 0; % R^2 for fit   

    % Initial parameter estimates
    init_k1 = 9.393e-4;
    init_r = 0.297;
    init_k2 = 0.022;
    init_m = 0.149;
    init_H0=[22.1  14.6  35 1.17 0.136];
      
    % Run fitting routine
    options = optimset('MaxFunEvals',1000);
    fixedpara = [d peak_pt]; % dilution rate is fixed, peak times fixed
    para1 = [init_k1 init_r init_k2 init_m init_H0]; % Initial parameters
    
    timepts = [];
    for jj = 1:length(keepN);
        timepts = [timepts Time]; % data time points
    end
    
    % Fit equations (S2.3) to time series
    [FitParms, resnorm, residual] = lsqcurvefit(...
        @(para,timepts)DiscLogistic_solution(para,timepts,fixedpara),...
        para1,timepts,DataN,zeros(1,length(para1)),[],options);
    
    % Save estimated parameters and error
        est_k1 = FitParms(1);% estimated k1 values
        est_r1 = FitParms(2);% estimated r values (r = b-m)
        est_k2 = FitParms(3);% estimated k2 values
        est_m = FitParms(4);% estimated m values
        est_H0 = FitParms(5:end); % estimated initial conditions
        error_1 = resnorm; % SSres (sum of residuals^2)
        R2 = 1 - resnorm/sumsqr(DataN-mean(DataN));% R^2 for fit
         
    % Compute estimated K value
        est_K = est_r1./((est_r1+est_m).*est_k2); % estimated K value
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    % Plot data and fits
    figure; 
    SimDensity = DiscLogistic_solution([est_k1 est_r1 est_k2 ...
            est_m est_H0], timepts,fixedpara);
                
    for jj = 1:length(keepN)
        subplot(2,3,jj)
        hold on
        plot(Time,DataN((jj-1)*10+1:jj*10),'-ob','LineWidth',3)
        plot(Time,SimDensity((jj-1)*10+1:jj*10),'-r','LineWidth',3)
        xlim([5 55])
        ylim([0 1200])
        set(gca,'Box','on','FontSize',16);
        set(gca,'XTick',[7 22 37 52],'YTick',[0 400 800 1200])
        xlabel('Day')
        ylabel('Density (num./L)')
        title(['Mesocosm ' num2str(keepN(jj))])
    end

